@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from typing import TYPE_CHECKING, List, Text, Tuple, overload
+from typing import TYPE_CHECKING, List, Optional, Text, Tuple, overload
 
 import attr
 from selenium.webdriver.common.by import By
@@ -61,21 +61,29 @@ class SeleniumCheckSettingsValues(CheckSettingsValues):
     selector = attr.ib(default=None)  # type: VisualGridSelector
     script_hooks = attr.ib(factory=dict)  # type: dict
     visual_grid_options = attr.ib(default=())  # type: Tuple[VisualGridOption]
+    disable_browser_fetching = attr.ib(default=None)  # type: Optional[bool]
 
     @property
     def size_mode(self):
-        if (
-            self.target_region is None
-            and self.target_selector is None
-            and self.target_element is None
-        ):
+        if self.is_target_empty:
             if self.stitch_content:
                 return "full-page"
             return "viewport"
-        if self.target_region:
+        elif self.target_region:
             return "region"
+        elif self.stitch_content:
+            return "full-selector"
         return "selector"
 
+    @property
+    def is_target_empty(self):
+        # type: () -> bool
+        return (
+            self.target_region is None
+            and self.target_selector is None
+            and self.target_element is None
+        )
+
 
 @attr.s
 class SeleniumCheckSettings(CheckSettings):
@@ -388,3 +396,13 @@ class SeleniumCheckSettings(CheckSettings):
         argument_guard.are_(options, VisualGridOption)
         self.values.visual_grid_options = options
         return self
+
+    def disable_browser_fetching(self, disable=True):
+        # type: (bool) -> SeleniumCheckSettings
+        self.values.disable_browser_fetching = disable
+        return self
+
+    @property
+    def is_check_window(self):
+        # type: () -> bool
+        return bool(self.values.is_target_empty and self.values.selector is None)
