@@ -28,8 +28,9 @@ from applitools.core import (
     RegionProvider,
     TextTrigger,
 )
+from applitools.core.feature import Feature
 
-from . import eyes_selenium_utils, useragent
+from . import eyes_selenium_utils
 from .__version__ import __version__
 from .capture import EyesWebDriverScreenshot, dom_capture
 from .capture.eyes_webdriver_screenshot import EyesWebDriverScreenshotFactory
@@ -37,7 +38,6 @@ from .capture.full_page_capture_algorithm import FullPageCaptureAlgorithm
 from .capture.image_providers import get_image_provider
 from .capture.screenshot_utils import cut_to_viewport_size_if_required
 from .classic_runner import ClassicRunner
-from .fluent import Target
 from .frames import FrameChain
 from .positioning import (
     CSSTranslatePositionProvider,
@@ -230,16 +230,10 @@ class SeleniumEyes(EyesBase):
         elif stitch_mode == StitchMode.CSS:
             return CSSTranslatePositionProvider(self.driver, scroll_root_element)
 
-    def check(self, name, check_settings=None):
-        # type: (Text, Optional[SeleniumCheckSettings]) -> MatchResult
+    def check(self, check_settings):
+        # type: (Text, SeleniumCheckSettings) -> MatchResult
         source = eyes_selenium_utils.get_check_source(self.driver)
-        if check_settings is None:
-            check_settings = Target.window()
-
-        if name:
-            check_settings = check_settings.with_name(name)
-        else:
-            name = check_settings.values.name
+        name = check_settings.values.name
 
         logger.info("check('{}', check_settings) - begin".format(name))
 
@@ -306,6 +300,11 @@ class SeleniumEyes(EyesBase):
             )
         elif check_settings:
             target_element = self._element_from(check_settings)
+            total_frames = len(check_settings.values.frame_chain)
+            if self.configure.is_feature_activated(
+                Feature.TARGET_WINDOW_CAPTURES_SELECTED_FRAME
+            ):
+                total_frames += self.driver.frame_chain.size
             if target_element:
                 logger.debug("have target element")
                 self._target_element = target_element
@@ -314,7 +313,7 @@ class SeleniumEyes(EyesBase):
                 else:
                     result = self._check_region(name, check_settings, source)
                 self._target_element = None
-            elif len(check_settings.values.frame_chain) > 0:
+            elif total_frames > 0:
                 logger.debug("have frame chain")
                 if self._stitch_content:
                     result = self._check_full_frame_or_element(
@@ -683,29 +682,21 @@ class SeleniumEyes(EyesBase):
     @property
     def _environment(self):
         os = self.configure.host_os
-        # If no host OS was set, check for mobile OS.
-        device_info = "Desktop"
+
+        device_info = (
+            self._driver.desired_capabilities.get("deviceName", "")
+            if self.driver.is_mobile_platform
+            else "Desktop"
+        )
+
+        # If no host OS was set, check for mobile OS
         if os is None:
             logger.info("No OS set, checking for mobile OS...")
-            # Since in Python Appium driver is the same for Android and iOS,
-            # we need to use the desired capabilities to figure this out.
-            if eyes_selenium_utils.is_mobile_app(self._driver):
-                platform_name = self._driver.platform_name
-                logger.info(platform_name + " detected")
-                device_info = self._driver.desired_capabilities.get("deviceModel", "")
-                platform_version = self._driver.platform_version
-                if platform_version is not None:
-                    # Notice that Python's "split" function's +limit+ is the the
-                    # maximum splits performed whereas in Ruby it is the maximum
-                    # number of elements in the result (which is why they are set
-                    # differently).
-                    major_version = platform_version.split(".", 1)[0]
-                    os = platform_name + " " + major_version
-                else:
-                    os = platform_name
+            if self._driver.is_mobile_app:
+                os = self.driver.user_agent.os_name_with_major_version
                 logger.info("Setting OS: " + os)
             else:
-                logger.info("No mobile OS detected")
+                logger.info("No mobile app detected. Using inferred environment")
         app_env = AppEnvironment(
             os,
             hosting_app=self.configure.host_app,
@@ -731,7 +722,7 @@ class SeleniumEyes(EyesBase):
     def _inferred_environment(self):
         # type: () -> Optional[Text]
         user_agent = self._driver.user_agent
-        if user_agent:
+        if user_agent.origin_ua_string:
             return "useragent:%s" % user_agent.origin_ua_string
         return None
 
@@ -745,10 +736,17 @@ class SeleniumEyes(EyesBase):
             return self._scale_provider
 
         logger.debug("Trying to extract device pixel ratio...")
+
         try:
-            device_pixel_ratio = eyes_selenium_utils.get_device_pixel_ratio(
-                self._driver
-            )
+            if (
+                self.driver.is_mobile_app
+                and Feature.SCALE_MOBILE_APP in self.configure.features
+            ):
+                device_pixel_ratio = self.driver.session["pixelRatio"]
+            else:
+                device_pixel_ratio = self._driver.execute_script(
+                    "return window.devicePixelRatio;"
+                )
         except Exception as e:
             logger.info(
                 "Failed to extract device pixel ratio! Using default. Error %s " % e
@@ -897,18 +895,16 @@ class SeleniumEyes(EyesBase):
             self._region_to_check, self._full_region_to_check, elem_position_provider
         )
         image = self._crop_if_needed(image)
-        return EyesWebDriverScreenshot.create_entire_frame(
-            self._driver, image, RectangleSize.from_(image)
+        return EyesWebDriverScreenshot.create_entire_element(
+            self._driver,
+            image,
+            RectangleSize.from_(image),
+            -self._full_region_to_check.location,
         )
 
     def _full_page_screenshot(self, scale_provider):
         # type: (ScaleProvider) -> EyesWebDriverScreenshot
         logger.info("Full page screenshot requested")
-        original_fc = self.driver.frame_chain.clone()
-        if original_fc.size > 0:
-            original_frame_position = original_fc.default_content_scroll_position
-        else:
-            original_frame_position = Point.ZERO()
 
         with self.driver.switch_to.frames_and_back(self._original_fc):
             scroll_root_element = eyes_selenium_utils.curr_frame_scroll_root_element(
@@ -933,7 +929,7 @@ class SeleniumEyes(EyesBase):
             )
             image = self._crop_if_needed(image)
             return EyesWebDriverScreenshot.create_full_page(
-                self._driver, image, original_frame_position
+                self._driver, image, -region.location
             )
 
     def _element_screenshot(self, scale_provider):
@@ -1005,6 +1001,12 @@ class SeleniumEyes(EyesBase):
                             self.driver, self._scroll_root_element
                         )
                     )
+                # This might happen when scroll root element is calculated in the
+                # beginning of SeleniumEyes.check when there is a frame in
+                # driver's frame_chain but it gets popped out and becomes check target
+                elif not self.scroll_root_element.is_attached_to_page:
+                    fc = self.driver.frame_chain.clone()
+                    scroll_root_element = self.driver.find_element_by_tag_name("html")
                 else:
                     fc = self.driver.frame_chain.clone()
                     scroll_root_element = self.scroll_root_element
