@@ -10,10 +10,10 @@ from applitools.common import (
     logger,
 )
 from applitools.common.ultrafastgrid import (
+    IRenderBrowserInfo,
     RenderRequest,
     RunningRender,
     VGResource,
-    IRenderBrowserInfo,
 )
 from applitools.core import (
     NULL_REGION_PROVIDER,
@@ -26,15 +26,17 @@ from applitools.selenium import Configuration
 from applitools.selenium.__version__ import __version__
 
 if typing.TYPE_CHECKING:
-    from typing import Text, List, Dict, Any, Optional
+    from typing import Any, Dict, List, Optional, Text
+
     from requests import Response
-    from applitools.common.ultrafastgrid import (
-        RenderingInfo,
-        RenderBrowserInfo,
-        RenderStatusResults,
-    )
+
     from applitools.common.match import MatchResult
     from applitools.common.test_results import TestResults
+    from applitools.common.ultrafastgrid import (
+        RenderBrowserInfo,
+        RenderingInfo,
+        RenderStatusResults,
+    )
     from applitools.selenium.fluent import SeleniumCheckSettings
 
 
@@ -150,6 +152,7 @@ class EyesConnector(EyesBase):
         check_task_uuid,  # type:  Text
         region_selectors,  # type: List[VisualGridSelector]
         regions,  # type: List[Region]
+        source,  # type: Optional[Text]
     ):
         # type:(...)->MatchResult
         self._current_uuid = check_task_uuid
@@ -159,7 +162,7 @@ class EyesConnector(EyesBase):
         self._region_selectors = region_selectors
         self._regions = regions
         check_result = self._check_window_base(
-            NULL_REGION_PROVIDER, name, False, check_settings
+            NULL_REGION_PROVIDER, name, False, check_settings, source
         )
         self._current_uuid = None
         self._region_selectors = []
@@ -173,6 +176,9 @@ class EyesConnector(EyesBase):
 
     def render_status_for_task(self, uuid, status):
         # type: (str, RenderStatusResults) -> None
+        logger.debug(
+            "render_status_for_task: uuid: {} \n\tstatus: {}".format(uuid, status)
+        )
         self._current_uuid = uuid
         self._render_statuses[uuid] = status
 
@@ -187,8 +193,8 @@ class EyesConnector(EyesBase):
             )
         return status
 
-    def _match_window(self, region_provider, tag, check_settings):
-        # type: (RegionProvider, Text, SeleniumCheckSettings) -> MatchResult
+    def _match_window(self, region_provider, tag, check_settings, source):
+        # type: (RegionProvider, Text, SeleniumCheckSettings, Optional[Text]) -> MatchResult
         # Update retry timeout if it wasn't specified.
         retry_timeout_ms = -1  # type: int
         if check_settings:
@@ -212,6 +218,7 @@ class EyesConnector(EyesBase):
             render_id=self.render_status.render_id,
             region_selectors=self._region_selectors,
             regions=self._regions,
+            source=source,
         )
 
     def _get_app_output_with_screenshot(self, region, last_screenshot, check_settings):
