@@ -1,4 +1,5 @@
 import typing
+from collections import Iterable, deque
 from functools import partial
 from itertools import chain
 
@@ -23,7 +24,7 @@ from applitools.selenium.parsers import collect_urls_from_
 from .vg_task import VGTask
 
 if typing.TYPE_CHECKING:
-    from typing import Any, Callable, Dict, List, NoReturn, Optional, Text
+    from typing import Any, Callable, Dict, List, NoReturn, Optional, Text, Tuple
 
     from applitools.common import Region, RenderingInfo, RenderStatusResults
     from applitools.selenium.visual_grid import (
@@ -214,53 +215,44 @@ class RenderTask(VGTask):
                 frames_num=len(frames),
             )
         )
-        frame_request_resources = {}
-        discovered_resources_urls = set()
 
-        def handle_resources(content_type, content, resource_url):
+        def find_child_resource_urls(content_type, content, resource_url):
             # type: (Optional[Text], bytes, Text) -> NoReturn
             logger.debug(
-                "handle_resources({0}, {1}) call".format(content_type, resource_url)
+                "find_child_resource_urls({0}, {1}) call".format(
+                    content_type, resource_url
+                )
             )
             if not content_type:
                 logger.debug("content_type is empty. Skip handling of resources")
-                return
-            for url in collect_urls_from_(content_type, content):
-                target_url = apply_base_url(url, base_url, resource_url)
-                discovered_resources_urls.add(target_url)
-
-        def get_resource(link):
-            # type: (Text) -> VGResource
-            logger.debug("get_resource({0}) call".format(link))
-            response = self.eyes_connector.download_resource(link)
-            return VGResource.from_response(link, response, on_created=handle_resources)
+                return []
+            return [
+                apply_base_url(url, base_url, resource_url)
+                for url in collect_urls_from_(content_type, content)
+            ]
 
+        frame_request_resources = {}
         for f_data in frames:
             f_data["url"] = apply_base_url(f_data["url"], base_url)
             frame_request_resources[f_data["url"]] = self.parse_frame_dom_resources(
                 f_data
             ).resource
 
+        urls_to_fetch = set(resource_urls)
         for blob in all_blobs:
-            resource = VGResource.from_blob(blob, on_created=handle_resources)
+            resource = VGResource.from_blob(blob, find_child_resource_urls)
             if resource.url.rstrip("#") == base_url:
                 continue
             frame_request_resources[resource.url] = resource
+            urls_to_fetch |= set(resource.child_resource_urls)
 
-        for r_url in set(resource_urls).union(discovered_resources_urls):
-            self.resource_cache.fetch_and_store(r_url, get_resource)
-        self.resource_cache.process_all()
-
-        # some discovered urls becomes available only after resources processed
-        for r_url in discovered_resources_urls:
-            self.resource_cache.fetch_and_store(r_url, get_resource)
-
-        for r_url in set(resource_urls).union(discovered_resources_urls):
-            val = self.resource_cache[r_url]
-            if val is None:
-                logger.debug("No response for {}".format(r_url))
-                continue
-            frame_request_resources[r_url] = val
+        resources_and_their_children = fetch_resources_recursively(
+            urls_to_fetch,
+            self.eyes_connector,
+            self.resource_cache,
+            find_child_resource_urls,
+        )
+        frame_request_resources.update(resources_and_their_children)
         self.full_request_resources.update(frame_request_resources)
         return RGridDom(
             url=base_url, dom_nodes=data["cdt"], resources=frame_request_resources
@@ -318,3 +310,38 @@ class RenderTask(VGTask):
             )
         self.running_tests.append(running_test)
         return len(self.running_tests) - 1
+
+
+def fetch_resources_recursively(
+    urls,  # type: Iterable[Text]
+    eyes_connector,  # type: EyesConnector
+    resource_cache,  # type: ResourceCache
+    find_child_resource_urls,  # type: Callable[[Text, bytes, Text],List[Text]]
+):
+    # type: (...) -> Iterable[Tuple[Text, VGResource]]
+    def get_resource(link):
+        logger.debug("get_resource({0}) call".format(link))
+        response = eyes_connector.download_resource(link)
+        return VGResource.from_response(link, response, find_child_resource_urls)
+
+    def schedule_fetch(urls):
+        for url in urls:
+            if url not in seen_urls:
+                seen_urls.add(url)
+                downloading = resource_cache.fetch_and_store(url, get_resource)
+                if downloading:  # going to take time, add to the queue end
+                    fetched_urls_deque.appendleft(url)
+                else:  # resource is already in cache, add to the queue front
+                    fetched_urls_deque.append(url)
+
+    fetched_urls_deque = deque()
+    seen_urls = set()
+    schedule_fetch(urls)
+    while fetched_urls_deque:
+        url = fetched_urls_deque.pop()
+        resource = resource_cache[url]
+        if resource is None:
+            logger.debug("No response for {}".format(url))
+        else:
+            schedule_fetch(resource.child_resource_urls)
+            yield url, resource
