@@ -140,33 +140,33 @@ class VisualGridEyes(object):
         logger.info("VisualGridEyes opening {} tests...".format(len(self.test_list)))
         return driver
 
-    def get_script_result(self):
-        # type: () -> Dict
+    def get_script_result(self, dont_fetch_resources):
+        # type: (bool) -> Dict
         logger.debug("get_script_result()")
-        skip_resources = json.dumps(
-            {"skipResources": list(copy(self.vg_manager.resource_cache.keys()))}
+        options = json.dumps(
+            {
+                "dontFetchResources": dont_fetch_resources,
+                "skipResources": list(copy(self.vg_manager.resource_cache.keys())),
+            }
         )
         process_resources = (
             PROCESS_RESOURCES
-            + "return __processPageAndSerializePoll(document, {});".format(
-                skip_resources
-            )
+            + "return __processPageAndSerializePoll({});".format(options)
         )
         if self.driver.user_agent.is_internet_explorer:
             process_resources = (
                 PROCESS_RESOURCES_FOR_IE
-                + "return __processPageAndSerializePollForIE(document, {});".format(
-                    skip_resources
-                )
+                + "return __processPageAndSerializePollForIE({});".format(options)
             )
 
         return eyes_selenium_utils.get_dom_script_result(
             self.driver, DOM_EXTRACTION_TIMEOUT, "VG_StopWatch", process_resources
         )
 
-    def check(self, name, check_settings):
-        # type: (Text, SeleniumCheckSettings) -> None
+    def check(self, check_settings):
+        # type: (SeleniumCheckSettings) -> None
         argument_guard.is_a(check_settings, CheckSettings)
+        name = check_settings.values.name
         logger.debug("VisualGridEyes.check(%s, %s)" % (name, check_settings))
         self._try_set_target_selector(check_settings)
 
@@ -177,7 +177,10 @@ class VisualGridEyes(object):
 
         region_xpaths = self.get_region_xpaths(check_settings)
         logger.info("region_xpaths: {}".format(region_xpaths))
-        script_result = self.get_script_result()
+        dont_fetch_resources = self._effective_disable_browser_fetching(
+            self.configure, check_settings
+        )
+        script_result = self.get_script_result(dont_fetch_resources)
         source = eyes_selenium_utils.get_check_source(self.driver)
         try:
             for test in self.test_list:
@@ -253,7 +256,9 @@ class VisualGridEyes(object):
             check_settings = check_settings.match_level(self.configure.match_level)
         if fully is None:
             fps = self.configure.force_full_page_screenshot
-            check_settings = check_settings.fully(True if fps is None else fps)
+            check_settings = check_settings.fully(
+                check_settings.is_check_window if fps is None else fps
+            )
         if send_dom is None:
             send = self.configure.send_dom
             check_settings = check_settings.send_dom(True if send is None else send)
@@ -384,3 +389,10 @@ class VisualGridEyes(object):
         except Exception as e:
             logger.exception(e)
             raise EyesError(str(e))
+
+    @staticmethod
+    def _effective_disable_browser_fetching(config, check_settings):
+        if check_settings.values.disable_browser_fetching is not None:
+            return check_settings.values.disable_browser_fetching
+        else:
+            return config.disable_browser_fetching
